@@ -3,8 +3,8 @@
 import Cocoa
 import sys
 
-image = Cocoa.NSImage.alloc().initWithContentsOfFile_(sys.argv[1].decode('utf-8'));
-binary = sys.argv[2].decode('utf-8');
+image = Cocoa.NSImage.alloc().initWithContentsOfFile_(sys.argv[1]);
+binary = sys.argv[2];
 options = 0;
 
 result = Cocoa.NSWorkspace.sharedWorkspace().setIcon_forFile_options_(image, binary, options);
