@@ -84,7 +84,8 @@ bool display_manager_active_display_is_animating(void);
 bool display_manager_display_is_animating(uint32_t did);
 int display_manager_active_display_count(void);
 uint32_t *display_manager_active_display_list(int *count);
-uint32_t display_manager_focus_display_with_point(CGPoint point, bool update_cursor_position);
+uint32_t display_manager_focus_display_with_window_at_point(CGPoint point);
+void display_manager_set_active_display_id(uint32_t did);
 void display_manager_focus_display(uint32_t did, uint64_t sid);
 enum space_op_error display_manager_focus_space(uint32_t did, uint64_t sid);
 bool display_manager_begin(struct display_manager *dm);
