@@ -270,6 +270,8 @@ static inline char *ts_string_escape(char *s)
             (*cursor == '\r') ||
             (*cursor == '\t')) {
             ++num_replacements;
+        } else if (*cursor >= 0x00 && *cursor <= 0x1f) {
+            num_replacements += 5;
         }
 
         ++cursor;
@@ -284,7 +286,7 @@ static inline char *ts_string_escape(char *s)
     for (char *dst = result, *cursor = s; *cursor; ++cursor) {
         if (*cursor == '"') {
             *dst++ = '\\';
-            *dst++ = *cursor;
+            *dst++ = '"';
         } else if (*cursor == '\\') {
             *dst++ = '\\';
             *dst++ = '\\';
@@ -303,6 +305,11 @@ static inline char *ts_string_escape(char *s)
         } else if (*cursor == '\t') {
             *dst++ = '\\';
             *dst++ = 't';
+        } else if (*cursor >= 0x00 && *cursor <= 0x1f) {
+            *dst++ = '\\';
+            *dst++ = 'u';
+            sprintf(dst, "%04x", (int)*cursor);
+            dst += 4;
         } else {
             *dst++ = *cursor;
         }
