@@ -34,6 +34,17 @@ error(const char *format, ...)
     exit(EXIT_FAILURE);
 }
 
+static inline void
+require(const char *format, ...)
+{
+    va_list args;
+    va_start(args, format);
+    vfprintf(stderr, format, args);
+    va_end(args);
+
+    exit(EXIT_SUCCESS);
+}
+
 static inline void
 debug_message(const char *prefix, char *message)
 {
