@@ -241,7 +241,7 @@ static bool scripting_addition_request_handshake(char *version, uint32_t *attrib
 {
     int sockfd;
     bool result = false;
-    char rsp[BUFSIZ] = {};
+    char rsp[BUFSIZ] = {0};
     char bytes[0x1000] = { 0x01, 0x00, SA_OPCODE_HANDSHAKE };
 
     if (socket_open(&sockfd)) {
@@ -271,7 +271,7 @@ out:
 static int scripting_addition_perform_validation(void)
 {
     uint32_t attrib = 0;
-    char version[0x1000] = {};
+    char version[0x1000] = {0};
     bool is_latest_version_installed = scripting_addition_check() == 0;
 
     if (!scripting_addition_request_handshake(version, &attrib)) {
@@ -602,6 +602,25 @@ bool scripting_addition_order_window_in(uint32_t *window_list, int window_count)
     return sa_payload_send(SA_OPCODE_WINDOW_ORDER_IN);
 }
 
+bool scripting_addition_move_window_list_to_space(uint64_t sid, uint32_t *window_list, int window_count)
+{
+    sa_payload_init();
+    pack(sid);
+    pack(window_count);
+    for (int i = 0; i < window_count; ++i) {
+        pack(window_list[i]);
+    }
+    return sa_payload_send(SA_OPCODE_WINDOW_LIST_TO_SPACE);
+}
+
+bool scripting_addition_move_window_to_space(uint64_t sid, uint32_t wid)
+{
+    sa_payload_init();
+    pack(sid);
+    pack(wid);
+    return sa_payload_send(SA_OPCODE_WINDOW_TO_SPACE);
+}
+
 #undef sa_payload_init
 #undef pack
 #undef sa_payload_send
