@@ -333,7 +333,17 @@ void space_manager_set_right_padding_for_all_spaces(struct space_manager *sm, in
     })
 }
 
-void space_manager_set_auto_balance_for_all_spaces(struct space_manager *sm, bool auto_balance)
+void space_manager_set_split_type_for_all_spaces(struct space_manager *sm, enum window_node_split split_type)
+{
+    sm->split_type = split_type;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_SPLIT_TYPE)) {
+            view->split_type = split_type;
+        }
+    })
+}
+
+void space_manager_set_auto_balance_for_all_spaces(struct space_manager *sm, uint32_t auto_balance)
 {
     sm->auto_balance = auto_balance;
     table_for (struct view *view, sm->view, {
@@ -463,8 +473,8 @@ void space_manager_toggle_window_split(struct space_manager *sm, struct window *
     if (node && window_node_is_intermediate(node)) {
         node->parent->split = node->parent->split == SPLIT_Y ? SPLIT_X : SPLIT_Y;
 
-        if (view->auto_balance) {
-            window_node_balance(view->root, SPLIT_X | SPLIT_Y);
+        if (view->auto_balance != SPLIT_NONE) {
+            window_node_balance(view->root, view->auto_balance);
             view_update(view);
             view_flush(view);
         } else {
@@ -1041,7 +1051,6 @@ bool space_manager_refresh_application_windows(struct space_manager *sm)
 {
     int refresh_count = buf_len(g_window_manager.applications_to_refresh);
     if (!refresh_count) return false;
-
     int window_count = g_window_manager.window.count;
     for (int i = 0; i < refresh_count; ++i) {
         struct application *application = g_window_manager.applications_to_refresh[i];
@@ -1052,7 +1061,6 @@ bool space_manager_refresh_application_windows(struct space_manager *sm)
             --i;
         }
     }
-
     return window_count != g_window_manager.window.count;
 }
 
@@ -1112,9 +1120,10 @@ void space_manager_begin(struct space_manager *sm)
 {
     sm->layout = VIEW_FLOAT;
     sm->split_ratio = 0.5f;
-    sm->auto_balance = false;
+    sm->auto_balance = SPLIT_NONE;
     sm->split_type = SPLIT_AUTO;
     sm->window_placement = CHILD_SECOND;
+    sm->window_insertion_point = INSERT_FOCUSED;
     sm->window_zoom_persist = true;
     sm->labels = NULL;
     table_init(&sm->view, 23, hash_view, compare_view);
